Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2619)

Unified Diff: chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc

Issue 1296663003: Componentize proxy code from chrome/browser/net (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: updating for win p/f Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/profiles/profile_impl.cc ('k') | chrome/browser/ui/prefs/prefs_tab_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc
diff --git a/chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc b/chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc
index 2f82aa31e49f1893cc405b43f46d62c760064624..aaba1356af2fdcc359330d6d44da9e5591a9df79 100644
--- a/chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc
+++ b/chrome/browser/renderer_context_menu/render_view_context_menu_unittest.cc
@@ -19,7 +19,6 @@
#include "chrome/browser/net/spdyproxy/data_reduction_proxy_chrome_settings_factory.h"
#include "chrome/browser/prefs/incognito_mode_prefs.h"
#include "chrome/browser/renderer_context_menu/render_view_context_menu_test_util.h"
-#include "chrome/common/pref_names.h"
#include "chrome/test/base/chrome_render_view_host_test_harness.h"
#include "chrome/test/base/testing_profile.h"
#include "components/data_reduction_proxy/core/browser/data_reduction_proxy_test_utils.h"
@@ -27,6 +26,7 @@
#include "components/data_reduction_proxy/core/common/data_reduction_proxy_headers.h"
#include "components/data_reduction_proxy/core/common/data_reduction_proxy_params.h"
#include "components/data_reduction_proxy/core/common/data_reduction_proxy_pref_names.h"
+#include "components/proxy_config/proxy_config_pref_names.h"
#include "content/public/browser/web_contents.h"
#include "content/public/test/web_contents_tester.h"
@@ -377,11 +377,11 @@ class RenderViewContextMenuPrefsTest : public ChromeRenderViewHostTestHarness {
DataReductionProxyChromeSettingsFactory::GetForBrowserContext(
profile());
// TODO(bengr): Remove prefs::kProxy registration after M46. See
// http://crbug.com/445599.
PrefRegistrySimple* registry =
drp_test_context_->pref_service()->registry();
- registry->RegisterDictionaryPref(prefs::kProxy);
+ registry->RegisterDictionaryPref(proxy_config::prefs::kProxy);
drp_test_context_->pref_service()->SetBoolean(
data_reduction_proxy::prefs::kDataReductionProxyEnabled,
« no previous file with comments | « chrome/browser/profiles/profile_impl.cc ('k') | chrome/browser/ui/prefs/prefs_tab_helper.cc » ('j') | no next file with comments »
@@ -377,11 +377,11 @@ class RenderViewContextMenuPrefsTest : public ChromeRenderViewHostTestHarness {
DataReductionProxyChromeSettingsFactory::GetForBrowserContext(
profile());
- // TODO(bengr): Remove prefs::kProxy registration after M46. See
- // http://crbug.com/445599.
+ // TODO(bengr): Remove proxy_config::prefs::kProxy registration after M46.
+ // See http://crbug.com/445599.
PrefRegistrySimple* registry =
drp_test_context_->pref_service()->registry();

Powered by Google App Engine
This is Rietveld 408576698